@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,9 +12,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import pytorch_lightning._graveyard.accelerator
 import pytorch_lightning._graveyard.callbacks
+import pytorch_lightning._graveyard.cli
 import pytorch_lightning._graveyard.core
 import pytorch_lightning._graveyard.legacy_import_unpickler
 import pytorch_lightning._graveyard.loggers
+import pytorch_lightning._graveyard.loops
+import pytorch_lightning._graveyard.profiler
+import pytorch_lightning._graveyard.strategies
 import pytorch_lightning._graveyard.trainer
-import pytorch_lightning._graveyard.training_type  # noqa: F401
+import pytorch_lightning._graveyard.training_type
+import pytorch_lightning._graveyard.utilities  # noqa: F401
